==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  "รายการสิ่งของที่มีอยู่"

]
, "Inventory item list, Inventory item lists"
: [
  ""

]
, "Name"
: "ชื่อ"

, "Status"
: "สถานะ"

, "Inventory ID"
: "รหัสรายการสิ่งของ"

, "Description"
: "การอธิบาย"

, "Location"
: "สถานที่"

, "Invoice date"
: "วันที่ของใบกำกับสินค้า"

, "Invoice"
: "ใบแจ้งกำกับสินค้า"

, "Price"
: "ราคา"

, "Cost Center"
: ""

, "Warranty"
: "การรับประกัน"

, "Item added"
: "สิ่งของได้เพิ่มแล้ว"

, "Item removed"
: "สิ่งของได้เอาออกแล้ว"

, "Deprecate"
: ""

, "The active number must be less than or equal total number."
: ""

, "General"
: "ทั่วไป"

, "ID"
: "รหัส"

, "Enter description"
: "ใส่ คำอธิบาย"

, "Added"
: "ได้เพิ่มแล้ว"

, "Removed"
: "เอาออกแล้ว"

, "Total number"
: "หมายเลขรวบยอด"

, "Available number"
: "หมายเลขที่มีอยู่"

, "Accounting"
: "การบัญชี"

, "Cost center"
: ""

, "Depreciate"
: ""

, "Default Inventory Item Container"
: ""

, "The default container for new items"
: ""

, "Inventory Status Available"
: ""

, "Possible status."
: "สถานะเป็นไปได้"

, "ordered"
: "สั่งแล้ว"

, "available"
: "มีอยู่"

, "defect"
: "ชำรุด"

, "missing"
: "หาย"

, "removed"
: "ได้เอาออก"

, "unknown"
: "ไม่รู้จัก"

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: "นำเข้ารายชื่อ  (###วันปัจจุบัน###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "สิ่งของถูกนำเข้าเมื่อ ###วันปัจจุบัน### ณ ###เวลาปัจจุบัน### โดย ###ชื่อเต็มของผู้ใช้###"

, "All Inventory Items"
: ""

, "All existing Inventory Items"
: ""

, "Inventory"
: ""

, "Inventory item"
: "รายการสิ่งของที่มีอยู่"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.03.4.tar.bz2: Inventory/js/Inventory-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: ""

, "The default container for new items"
: ""

, "The active number must be less than or equal total number."
: ""

, "General"
: "ทั่วไป"

, "ID"
: "รหัส"

, "Name"
: "ชื่อ"

, "Description"
: "การอธิบาย"

, "Enter description"
: "ใส่ คำอธิบาย"

, "Location"
: "สถานที่"

, "Added"
: "ได้เพิ่มแล้ว"

, "Warranty"
: "การรับประกัน"

, "Removed"
: "เอาออกแล้ว"

, "Total number"
: "หมายเลขรวบยอด"

, "Available number"
: "หมายเลขที่มีอยู่"

, "Status"
: "สถานะ"

, "Accounting"
: "การบัญชี"

, "Price"
: "ราคา"

, "Cost center"
: ""

, "Invoice"
: "ใบแจ้งกำกับสินค้า"

, "Invoice date"
: "วันที่ของใบกำกับสินค้า"

, "Depreciate"
: ""

, "All Inventory Items"
: ""

, "All existing Inventory Items"
: ""

, "Inventory"
: ""

, "Inventory Status Available"
: ""

, "Possible status."
: "สถานะเป็นไปได้"

, "ordered"
: "สั่งแล้ว"

, "available"
: "มีอยู่"

, "defect"
: "ชำรุด"

, "missing"
: "หาย"

, "removed"
: "ได้เอาออก"

, "unknown"
: "ไม่รู้จัก"

, "Inventory item, Inventory items"
: [
  "รายการสิ่งของที่มีอยู่"

]
, "Inventory item list, Inventory item lists"
: [
  ""

]
, "Inventory ID"
: "รหัสรายการสิ่งของ"

, "Cost Center"
: ""

, "Item added"
: "สิ่งของได้เพิ่มแล้ว"

, "Item removed"
: "สิ่งของได้เอาออกแล้ว"

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: "นำเข้ารายชื่อ  (###วันปัจจุบัน###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "สิ่งของถูกนำเข้าเมื่อ ###วันปัจจุบัน### ณ ###เวลาปัจจุบัน### โดย ###ชื่อเต็มของผู้ใช้###"

, "Inventory item"
: "รายการสิ่งของที่มีอยู่"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
